.. pyspaceweather documentation master file, created by
   sphinx-quickstart on Wed Mar 21 21:56:58 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pyspaceweather
==============

Python interface for space weather indices

The source code is `developed on Github <https://github.com/st-bender/pyspaceweather>`_.

.. image:: https://github.com/st-bender/pyspaceweather/actions/workflows/ci_build_and_test.yml/badge.svg?branch=master
    :target: https://github.com/st-bender/pyspaceweather/actions/workflows/ci_build_and_test.yml
    :alt: builds
.. image:: https://readthedocs.org/projects/pyspaceweather/badge/?version=latest
    :target: https://pyspaceweather.readthedocs.io/en/latest/?badge=latest
    :alt: docs
.. image:: https://img.shields.io/pypi/v/spaceweather.svg?style=flat
    :target: https://pypi.org/project/spaceweather
    :alt: pypi
.. image:: https://img.shields.io/pypi/wheel/spaceweather.svg?style=flat
    :target: https://pypi.org/project/spaceweather
    :alt: wheels
.. image:: https://img.shields.io/pypi/pyversions/spaceweather.svg?style=flat
    :target: https://pypi.org/project/spaceweather
    :alt: python
.. image:: https://codecov.io/gh/st-bender/pyspaceweather/badge.svg
    :target: https://codecov.io/gh/st-bender/pyspaceweather
    :alt: codecov
.. image:: https://coveralls.io/repos/github/st-bender/pyspaceweather/badge.svg
    :target: https://coveralls.io/github/st-bender/pyspaceweather
    :alt: coveralls
.. image:: https://scrutinizer-ci.com/g/st-bender/pyspaceweather/badges/quality-score.png?b=master
    :target: https://scrutinizer-ci.com/g/st-bender/pyspaceweather/?branch=master
    :alt: scrutinizer

.. toctree::
    :maxdepth: 2
    :caption: Introduction

    README

.. toctree::
    :maxdepth: 3
    :caption: Reference

    reference/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
